@@ -11,8 +11,8 @@ class Person(KinopoiskObject):
 
     photos = []
 
-    def __init__(self, **kwargs):
-        super(Person, self).__init__(**kwargs)
+    def __init__(self, *args, **kwargs):
+        super(Person, self).__init__(*args, **kwargs)
         from sources import PersonLink, PersonMainPage, PersonPhotosPage # import here for successful installing via pip
         self.register_source('link', PersonLink)
         self.register_source('main_page', PersonMainPage)
